function y  = genlaprnd(m, n, mu, sigma, alpha)
%LAPRND generate i.i.d. laplacian random number drawn from laplacian distribution
%   with mean mu and standard deviation sigma.
%   mu      : mean
%   sigma   : standard deviation
%   [m, n]  : the dimension of y.
%   Default mu = 0, sigma = 1.
%   For more information, refer to
%   http://en.wikipedia.org./wiki/Laplace_distribution

%   Author  : Elvis Chen (bee33@sjtu.edu.cn)
%   Date    : 01/19/07
% figure,
% 
% for r=1
%     y1 = genlaprnd(10000, 1, 0, 1, 0);
%     y2 = genlaprnd(10000, 1, 0, 1, 1);
%     [x1 n1] = hist(y1,100);
%     [x2 n2] = hist(y2,100);
%     plot(n1,x1,'r'),hold on,
%     plot(n2,x2,'k'),
% end

if alpha==0
    %Check inputs
    if nargin < 2
        error('At least two inputs are required');
    end

    if nargin == 2
        mu = 0; sigma = 1;
    end

    if nargin == 3
        sigma = 1;
    end

    % Generate Laplacian noise
    u = rand(m, n)-0.5;
    b = sigma / sqrt(2);
    y = mu - b * sign(u).* log(1- 2* abs(u));
else
    
    x = linspace(-20*sigma,20*sigma,m);
    p = exp(-(abs(x-mu)/sigma).^alpha);
    c = monotono2(cumsum(p));
    c = c/max(c);
    yy = rand(m,1);
    y = interp1(c,x,yy);
    
end
