function [dato xf idxLapla idxUnifo] = mani_cuerno_7(N,porc,porc2,gamma1,gamma2)

%
% MANI_CUERNO_7 generates N data from a 2D noisy swiss roll manifold with supergaussian
% distributions in the orthogonal dimension to the fisrt PC.
%
% A certain percentage of data (porc) follow a supergaussian with exponent gamma1 
% and the remaining follow a different suppergaussian with exponent gamma2. 
% (gamma=2 -> Gaussian, gamma<2 -> leptokurtotic, gamma>2 -> platykurtotic).
% porc=1 -> 100%. 
%
% In order to control the swiss roll parameters (number and speed of turns, scaling etc...) 
% please edit this function.
% The range of parameters analyzed in parameters_SPC.m is suited to the
% scaling of the data generated by this function. Parameters with geometric
% meaning should scale according to the scale of your data.
%
% Example:
%
%   N = 2000;       % Number of samples  
%   porc = 0.5;     % Percentage (between 0 and 1) of leptokurtotic samples 
%   porc2 = 0.1;    % Percentage of not-considered extreme (between 0 and 1)
%   gamma1 = 1;     % Exponent leptokurtotic 
%   gamma2 = 10;    % Exponent platykurtotic
%
% [datos datos_PC idxgamma1 idxgamma2] =mani_cuerno_7(N,porc,porc2,gamma1,gamma2);
%
%

rand('seed',123)
randn('seed',123)

alpha = 10;
beta = 80;
t = rand(1,N)/2; 
t = t(find(t>porc2*0.5));

idxLapla = find(t<porc*0.5); nL = length(idxLapla);
idxUnifo = find(t>=porc*0.5&t>porc2*0.5); nU = length(idxUnifo);

ruido(idxLapla) = t(idxLapla).*genlaprnd(nL,1,0,1,gamma1)';  % laplacian
ruido(idxUnifo) = 20*t(idxUnifo).*genlaprnd(nU,1,0,1,gamma2)';  % laplacian
% ruido(idxUnifo) = 5*t(idxUnifo).*randn(nU,1)';  % gaussian
% ruido(idxUnifo) = 35*t(idxUnifo).*(rand(nU,1)-0.5)';  % uniform
dato(1,:) = (beta*t + ruido).*cos(alpha*t);
dato(2,:) = (beta*t + ruido).*sin(alpha*t);
xf(1,:) = (beta*t).*cos(alpha*t);
xf(2,:) = (beta*t).*sin(alpha*t);

% Data normalization (convenient to use the range of parameters)
M = mean(dato,2);
dato = (dato - repmat(M,1,size(dato,2)));  
Maxx = max(dato(:));
dato = 10*dato/Maxx;
xf = (xf - repmat(M,1,size(dato,2)));  
xf = 10*xf/Maxx;

